@@ -1,11 +1,11 @@
 __author__ = "Wytze Bruinsma"
 
 import os
-import re
-import requests
-from PIL import Image
 from dataclasses import dataclass
 from io import BytesIO
+
+import requests
+from PIL import Image
 from vaknl_gcp.Storage import StorageClient
 
 
@@ -51,7 +51,7 @@ class ImageClient(object):
 
     def __init__(self, project_id):
         self.project_id = project_id
-        self.storage_client = StorageClient(project_id=project_id)
+        self.storage_client = StorageClient(project=project_id)
 
     @staticmethod
     def get_image(image_url, auth=None, headers=None):
@@ -78,7 +78,7 @@ class ImageClient(object):
         if image:
             bucket = self.storage_client.get_bucket(f'{bucket_name}-{self.project_id}')
             blob = bucket.blob(f"{id}/{file_name}")
-            new_image_url = self.storage_client.upload_from_string(blob, image)
+            new_image_url = blob.upload_from_string(image)
             return width, heigth, byte_size, new_image_url
         else:
-            return None, None, None, None, None
+            return None, None, None, None
